@@ -1,6 +1,7 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -10,8 +11,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.8',
- 'BLDLIBRARY': '-L. -lpython3.8',
+ 'BINLIBDEST': '/usr/lib/python3.9',
+ 'BLDLIBRARY': '-L. -lpython3.9',
  'BLDSHARED': 'gcc -pthread -shared '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
               '-fno-semantic-interposition '
@@ -23,23 +24,22 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
-           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
-           '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt',
+           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt '
+           '-fno-semantic-interposition -march=armv6 -mfloat-abi=hard '
+           '-mfpu=vfp -O3 -pipe -fno-plt -march=armv6 -mfloat-abi=hard '
+           '-mfpu=vfp -O3 -pipe -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                     '-fstack-protector-strong -fno-plt '
-                     '-fno-semantic-interposition',
+                     '-fno-plt -fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
  'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
                       '-fno-semantic-interposition',
@@ -49,24 +49,24 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'CFLAGS=-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe "
-                '-fstack-protector-strong -fno-plt '
+                "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv6 "
+                '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt '
                 "-fno-semantic-interposition' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
                 "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.8',
+ 'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.8.5/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.8.5/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.9.1/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.9.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.8 /usr/lib/python3.8/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.8',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.9 /usr/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -88,13 +88,14 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-38-arm-linux-gnueabihf.so',
+ 'EXT_SUFFIX': '.cpython-39-arm-linux-gnueabihf.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -172,6 +173,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
+ 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
@@ -249,7 +251,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -285,14 +286,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_J1939_H': 1,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
+ 'HAVE_LINUX_WAIT_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -344,7 +348,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
@@ -496,7 +499,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 1,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -522,16 +524,16 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'armv6l-unknown-linux-gnueabihf',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.8 '
-                   '/usr/include/python3.8',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.9 '
+                   '/usr/include/python3.9',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.8',
+ 'INCLUDEPY': '/usr/include/python3.9',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
@@ -539,24 +541,24 @@ build_time_vars = {'ABIFLAGS': '',
             '-fno-semantic-interposition '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
              '-fno-semantic-interposition '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'LDVERSION': '3.8',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.8',
+ 'LIBDEST': '/usr/lib/python3.9',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.8/config-3.8-arm-linux-gnueabihf',
+ 'LIBPL': '/usr/lib/python3.9/config-3.9-arm-linux-gnueabihf',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
@@ -571,7 +573,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.8',
+ 'MACHDESTLIB': '/usr/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -582,7 +584,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  xxsubtype',
+                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -595,7 +597,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'arm-linux-gnueabihf',
@@ -615,9 +617,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
@@ -633,44 +639,41 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3.8',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv6 -mfloat-abi=hard '
-                             '-mfpu=vfp -O3 -pipe -fstack-protector-strong '
-                             '-fno-plt -fno-semantic-interposition '
+                             '-mfpu=vfp -O3 -pipe -fno-plt '
+                             '-fno-semantic-interposition -march=armv6 '
+                             '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt '
                              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
-                             '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-pipe -fno-plt -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I./Include/internal -I. -I./Include '
-                             '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC '
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -D_FORTIFY_SOURCE=2 '
+                             '-D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
-              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
-              '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt',
+              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt '
+              '-fno-semantic-interposition -march=armv6 -mfloat-abi=hard '
+              '-mfpu=vfp -O3 -pipe -fno-plt -march=armv6 -mfloat-abi=hard '
+              '-mfpu=vfp -O3 -pipe -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I./Include/internal',
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt '
-                   '-fno-semantic-interposition -march=armv6 -mfloat-abi=hard '
-                   '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt '
-                   '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-fno-plt -fno-semantic-interposition -march=armv6 '
+                   '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt -march=armv6 '
+                   '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fno-plt -std=c99 '
+                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
                    '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
@@ -686,17 +689,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
-                        '-pipe -fstack-protector-strong -fno-plt '
-                        '-fno-semantic-interposition -march=armv6 '
-                        '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -march=armv6 '
-                        '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I./Include/internal -I. -I./Include '
-                        '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC',
+                        '-pipe -fno-plt -fno-semantic-interposition '
+                        '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+                        '-fno-plt -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
+                        '-pipe -fno-plt -std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 '
+                        '-fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -705,7 +706,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.5',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.1',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -733,8 +734,8 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38-arm-linux-gnueabihf',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-39-arm-linux-gnueabihf',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -747,19 +748,20 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.5 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.1 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.5 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.9.1 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.8 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.9 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.8',
+ 'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -771,8 +773,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.8.5',
- 'abs_srcdir': '/build/python/src/Python-3.8.5',
+ 'abs_builddir': '/build/python/src/Python-3.9.1',
+ 'abs_srcdir': '/build/python/src/Python-3.9.1',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
